summaryrefslogtreecommitdiffstats
path: root/kdf/listview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdf/listview.cpp')
-rw-r--r--kdf/listview.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kdf/listview.cpp b/kdf/listview.cpp
index 49021ee..b9274c3 100644
--- a/kdf/listview.cpp
+++ b/kdf/listview.cpp
@@ -20,7 +20,7 @@
//
// 1999-11-28 Espen Sand
// The purpose of this class is:
// 1) Easily set minimum number of visible items and to adjust the tqsizeHint()
// 2) Provide a pixmap collection
//
@@ -46,20 +46,20 @@ void CListView::setVisibleItem( int visibleItem, bool updateSize )
mVisibleItem = TQMAX( 1, visibleItem );
if( updateSize == true )
{
- TQSize s = tqsizeHint();
- setMinimumSize( s.width() + verticalScrollBar()->tqsizeHint().width() +
+ TQSize s = sizeHint();
+ setMinimumSize( s.width() + verticalScrollBar()->sizeHint().width() +
lineWidth() * 2, s.height() );
}
}
-TQSize CListView::tqsizeHint( void ) const
+TQSize CListView::sizeHint( void ) const
{
- TQSize s = TQListView::tqsizeHint();
+ TQSize s = TQListView::sizeHint();
int h = fontMetrics().height() + 2*itemMargin();
if( h % 2 > 0 ) { h++; }
- s.setHeight( h*mVisibleItem + lineWidth()*2 + header()->tqsizeHint().height());
+ s.setHeight( h*mVisibleItem + lineWidth()*2 + header()->sizeHint().height());
return( s );
}
@@ -20,7 +20,7 @@
// 1999-11-28 Espen Sand
// The purpose of this class is:
-// 1) Easily set minimum number of visible items and to adjust the tqsizeHint()
+// 1) Easily set minimum number of visible items and to adjust the sizeHint()
// 2) Provide a pixmap collection
//